/*************************************************************************************
This program computes the long term exposure to MeHg

INSTALLATION:
1/ Create a library "Stmod" pointing to the folder containing the datasets
- agesem.sas7bdat
- poidsest.sas7bdat
- poidssem.sas7bdat
- tbli_out.sas7bdat
- true_tblh.sas7bdat
2/ Run the auxiliary macro "macroevalexpo.sas" before the main program


INPUT DATABASE: 
1/ Stmod.true_tblh contains the rescaled household exposure, and the socio economic household variable
Variables: 
NOPNLT: household number
SM52: Week 
Sexpo: household exposure
CLAS: income class, 1 for rich, 2 for mean sup (ref.), 3 for mean inf, 4 for modest
REGPOIS2: region of residence, 1 for Paris and North, Britain, Vendee coast dpts, 2 for South west dpts, 3 for Mediterranean coast dpts, 4 for Non coastal dpts (ref.)
CSPPPOIS2: Professional category of head, 1 for white collar, 2 for Blue collar and self employed (ref.), 3 for retired, and 4 for no activity
DIPPOIS2: Diploma of the head, 1 for bac and higher degree, 2 for student, 3 for no or weak diploma
kvp: SECODIP household weight
XF, XM: fixed effect variables for female and male respectively
ZF, ZM: random effect variables for female and male respectively
WSM52i: weekly dummy
WCLASi: dummy of the class i
WREGPOIS2i: dummy of the region (REGPOIS2) i
WDIPPOIS2i: dummy of the diploma (DIPPOIS2) i
WCSPPOIS2i: dummy of the professional category of head (CSPPOIS2) i
Y: household exposure divided by the square root of the number of members in the household above one year (nbpersB)
nbpersB: number of members in the household above one year + those that will have one year in 2001

2/ Stmod.tbli_out
Variables: 
NOPNLT: household number
num: number of member in the household
age: age in years
SM52: Week where sea food products or/and fish are consumed
sex: gender, 1 for male, 2 for female
XF, XM: fixed effect variables for female and male respectively
ZF, ZM: random effect variables for female and male respectively
CLAS: income class, 1 for rich, 2 for mean sup (ref.), 3 for mean inf, 4 for modest
REGPOIS2: region of residence, 1 for Paris and North, Britain, Vendee coast dpts, 2 for South west dpts, 3 for Mediterranean coast dpts, 4 for Non coastal dpts (ref.)
DIPPOIS2: Diploma of the head, 1 for bac and higher degree, 2 for student, 3 for no or weak diploma
CSPPPOIS2: Professional category of head, 1 for white collar, 2 for Blue collar and self employed (ref.), 3 for retired, and 4 for no activity
WSM52i: weekly dummy
WCLASi: dummy of the income class i
WREGPOIS2i: dummy of the region i
WDIPPOIS2i: dummy of the diploma i
WCSPPOIS2i: dummy of the professional category of head i

3/ Stmod.agesem contains the weekly body weight for each member of the households
Variables
nopnlt num age sm52 agesemc inc 
NOPNLT: household number
num: number of the member 
age: age in years
sm52: N of the week where sea food products or/and fish are consumed
agesemc: age in week
inc: dummy variable that indicates if the individual is more than 1 years old (is included in the disaggregation).

4/ Stmod.poidsest and St mod.Poidssem contain the estimated body weight by age or agesem and sex.
Variable poids is the body weight corresponding to the age/agesem and sex.



14/09/2006 16:43
*************************************************************************************/

/************************
1/ Estimation of the final model
************************/

/* 1.1 PROC MIXED, see the help of the SAS software */

proc mixed data=Stmod.true_tblh IC method=REML covtest;

/* List of categorical variables */
class nopnlt nbpersb sm52;

/* Definition of the model, fixed effects*/
model Y= XF0 XF1 XM0 XM1 W1-W62/ s noint ;

/* Definition of the model, Random effects + variance of the random effects u*/
random ZF1-ZF23 ZM1-ZM22 /s type=toep(1) ;

/* Choice of the variance structure for the errors \epsilon*/
repeated sm52 /type=vc subject=nopnlt group=nbpersb;

/*Weighting of the households*/
weight kvp;

/* Tests for the Selection of the sociodemographic covariates/modalities for the FINAL MODEL*/
contrast 'test0 class'  W52 1,W53 1,W54 1;
contrast 'test1 class'  W52 1 W53 -1,W52 1 W54 -1,W53 1 W54 -1;
contrast 'test1a class' W52 1 W53 -1;
contrast 'test1b class' W52 1 W54 -1;
contrast 'test1c class' W53 1 W54 -1;

contrast 'test region'   W55 1,W56 1,W57 1;
contrast 'test1 region'  W55 1 W56 -1,W55 1 W57 -1, W56 1 W57 -1;
contrast 'test1a region' W55 1 W56 -1;
contrast 'test1b region' W55 1 W57 -1;
contrast 'test1c region' W56 1 W57 -1;

contrast 'test diploma'   W58 1,W59 1;
contrast 'test1 diploma'  W58 1 W59 -1;

contrast 'test CSP'   W60 1,W61 1,W62 1;
contrast 'test1 CSP'  W60 1 W61 -1,W60 1 W62 -1,W61 1 W62 -1;
contrast 'test1a CSP' W60 1 W61 -1;
contrast 'test1b CSP' W60 1 W62 -1;
contrast 'test1c CSP' W61 1 W62 -1;

/*Creation of output tables, results partly presented in table 4 of the paper*/
ods output solutionF=Stmod.estF_reml solutionR=Stmod.estR_reml InfoCrit=L1 covparms=Stmod.cp_corit_reml contrasts=Stmod.contrast_reml;

run;
/* Estimation of rho and sigma by Asymptotic Least Square*/

data cp;
set Stmod.cp_corit_reml;
if covparm="sm52";
taille=_N_-1;
run;

proc reg data=cp OUTEST=Stmod.estimrho covout;
model Estimate=Taille/covb;
run;quit;
/* 
a and Va =coef and Variance of taille
b and Vb =coef and Variance of intercept
C= Covariance Taille-Intercept
sig2= a+b
rho= a/(a+b)
V(sig2)=Va+Vb+2C
V(rho)=(b^2Va + a^2 Vb -2*a*b*C) / (a+b)^4
*/

/* 1.2 Fitted individual exposure using the macro "%evalexpo", denoted expo in the output file Stmod.expo_S0*/

data temp;
set Stmod.tbli_out;
if clas ne .;
run;

options mstored sasmstore= Stmod;
%evalexpo(TBL_I=temp,date=SM52,estimF=Stmod.estF_reml,estimR=Stmod.estR_reml,KF=23,KM=22,nbw=62);

data Stmod.expo_S0;
set temp;
run;

/* Please choose a scenario */

data expo;
set Stmod.expo_s0;
drop XF0 XF1 XM0 XM1 ZF1-ZF23 ZM1-ZM22 W1-W62;
expo_S=expo;
*expo_S0=expo;
*expo_S1=expo*1.2;	/*S1  : out of home consumption +20%*/
*expo_S2=expo*0.61;	/* S2 : edible part -39%*/
*expo_S3=expo*1.2*0.61;	/*S3  : out of home + edible -26.8%*/
run;

/************************
2/ Individual exposure weighted by the weekly and yearly body weight
************************/

/* 2.1- annual weight */

proc sort data=expo;by age sex;run;
proc sort data=Stmod.poidsest;by age sex;run;
data tpoids;
merge expo Stmod.poidsest;
by age sex;
if nopnlt ne .;
run;

/* 2.2- Weekly weight */

/* 2.2.a) Age in week */
proc sort data=Tpoids;
by nopnlt num sm52;run;
proc sort data=Stmod.agesem;
by nopnlt num sm52;run;
data T1;
merge Tpoids Stmod.agesem;
by nopnlt num sm52;
run;

/* 2.2.b) Weekly weight */
proc sort data=T1;by agesemc sex;run;
proc sort data=Stmod.poidssem;by agesemc sex;run;
data Tpoid_sem;
merge T1 Stmod.poidssem;
by agesemc sex;
if nopnlt ne .;
run;
proc sort data=Tpoid_sem; by nopnlt sm52;run;

/* 2.3 The individual weekly exposure expressed on a body weight basis */
data Expo_poid;
set Tpoid_sem;
if agesemc<=950 then expokg=expo_S/poidssem; /* the indivual exposure for a consumer below 18 years old */
if agesemc>950 then expokg=expo_S/poids;
if expo_S=0 or expo_S=. then expokg=0;
keep nopnlt num sm52 age sex expokg inc;
run;

/************************
3. Cumulative Individual exposure and long term risk implementations
************************/

/* 3.1 Implementation of the initial individual exposure SM52=0*/

proc sort data=expo_poid;by nopnlt num;run;
proc summary data=Expo_poid;
var expokg inc;
by nopnlt num;
output out=tirisk sum=expotot inctot;
run;

data tirisk_ini;
set tirisk;
drop _type_ _freq_;
sm52=0;
if inctot>0 then expomoy=expotot/inctot ;
else expomoy=0;
run;

data temp;
set expo_poid tirisk_ini;
if expokg=. then expokg=0;
if expokg>1.6 then risk=1 ; else risk=0;
run;

proc sort data=temp;by nopnlt num sm52;run;


/* 3.2.a Implementation of the cumulative individual exposure */

data expocum;
set temp;
if sm52=0 then expocum=expomoy;
retain expocum;
if inc=0 then expocum=expocum;
if sm52>0 and inc=1 then expocum=expocum*exp(-log(2)/6)+expokg;
run;

/* 3.2.b test if individual expocum is above the reference expocum */

data Stmod.expocum;
set expocum;
riskcum=(expocum>1.6*(exp(-log(2)*(sm52+1)/6)-1)/(exp(-log(2)/6)-1));
run;

/* 3.3 Long term risk  (sm52 >=30)*/

data risk30;
set Stmod.expocum;
if sm52 >=30;
run;

proc sort data=risk30;by nopnlt num;run;
proc summary data=risk30;
var riskcum;
by nopnlt num;
output out=maxrisk max=maxriskcum30;
run;

data age30;
set Stmod.agesem;
if sm52=30; 
agesem30=agesemc;
keep nopnlt num agesem30;
run;

proc sort data=expo;by nopnlt num;run;
proc summary data=expo;
by nopnlt num;
var clas regpois2 dippois2 csppois2;
output out=socioindiv max=clas regpois2 dippois2 csppois2;
run;

data risk_agesocio30;
merge socioindiv age30 maxrisk;
by nopnlt num;
if agesem30<=52 then indage=1;
if agesem30>52 and agesem36<=156 then indage=2;
if agesem30>156 then indage=3;
drop _type_ _freq_;
run;

/* Give the % of vulnerable consumer */
proc sort  data=risk_agesocio30;by indage;run; 
proc means data=risk_agesocio30;
var maxriskcum30;
run;

/* Give the % of vulnerable consumer by age */
proc means data=risk_agesocio30;
by indage;
var maxriskcum30;
run;


/* 4. Other outputs of the paper:
- Figures 1 and 2 were obtained by a univariate procedure on the residuals of the regression.
- The plot in Figure 3 was obtained by a TPSPLINE procedure.
- Figures 4 and 5 were obtained by applying the present program to the INCA dataset.
- Figure 6 of the paper was obtained by selecting certain individual in table expocum according to the value of expocum for the last week (sm52=53), a SAS macro was written by the authors and is available on request to tressou@agroparistech.fr 
- The mean risk (R_{1.6}) calculated as the percentage of weekly intakes exceeding the PTWI is simply obtained by creating a variable risk=(expokg>1.6) and doing a proc means on this variable in table Stmod.expocum.
*/ 
