options mstored sasmstore=Stmod; /* Indicates where macros will be stored, in the library Stmod*/

%macro evalexpo(TBL_I=,nopnlt=nopnlt,date=0,expo=Expo,estimF=,estimR=,KF=,KM=,nbW=)/store;
/* Tbl_i is the input table, expo is the name that will be given to the created variable estimating the exposure (default Expo), estimF is the output table of the proc mixed for fixed effects, estimR is the output table of the proc mixed for random effects, KF and KM is the number of nodes in the spline representation, respectively for male and female, nbw is the number of dummy variables (time+ socioeconomic variables) */

/* Drop variable expo in case it is present in the input table tbl_i*/
data &tbl_i;
set &tbl_i;
drop &expo;
run;

/* Create a list of the variables in tbl_i  and macro variables refering to their positions*/
proc contents data=&TBL_I out=desc noprint;run;
proc sort ;by varnum;run;

data _NULL_;
set desc;
%do i=0 %to 1;
if NAME="XF&i" then call symput("cXF&i",varnum);
if NAME="XM&i" then call symput("cXM&i",varnum);
%end;
%if &nbw ne 0 %then %do;
if NAME="W1" then call symput("debW",varnum);
if NAME="W&nbW" then call symput("finW",varnum);
%end;
if NAME="ZF1" then call symput("debZ",varnum);
if NAME="ZM&KM" then call symput("finZ",varnum);
run;

/* Compute the quantities X \beta +Z u + W \gamma to get the estimation of the individual quantities using iml (SAS matrix language)*/
proc iml;
use desc;
read all var {NAME} into lnames;
use &estimF;
read all var {estimate} into estF;
use &estimR;
read all var {estimate} into estR;
use &tbl_I;
read all var _num_ into TI;
X=TI[,&cXF0];
%do i=1 %to 1;
X=X||TI[,&&cXF&i];
%end;
X=X||TI[,&cXM0];
%do i=1 %to 1;
X=X||TI[,&&cXM&i];
%end;
%if (&nbw ne 0) %then %do; XW=X||(TI[,&debW:&finW]);%end; 
%else %do; XW=X;estF=estF[1:4,];%end;
expoI=XW*estF+TI[,&debZ:&finZ]*estR; 	/* Calculation of the individual exposure*/

tout=TI||expoI;
lnames=lnames//"&expo";

create expo from tout [colname=lnames];
append from tout;
quit;

/* A table expo including the new variable Expo was created from the iml procedure, it is merged to the input table*/
data &tbl_I;
merge &tbl_I expo;
run;

/* Useless tables are deleted */
proc datasets nolist ;
delete desc expo;quit;

%mend;
